@@ -6,7 +6,7 @@ use Moo;
 
 extends 'Perinci::To::PackageBase';
 
-our $VERSION = '0.26'; # VERSION
+our $VERSION = '0.27'; # VERSION
 
 sub BUILD {
     my ($self, $args) = @_;
@@ -103,15 +103,15 @@ sub _fdoc_gen {
             summary => $self->loc(join(
                 "",
                 "To undo, pass -undo_action=>'undo' to function. ",
-                "You will also need to pass -undo_data, unless you use ",
-                "transaction. For more details on undo protocol, ",
-                "see L<Rinci::function::Undo>.")),
+                "You will also need to pass -undo_data. ",
+                "For more details on undo protocol, ",
+                "see L<Rinci::Undo>.")),
         };
         $spargs{-undo_data} = {
             type => 'array',
             summary => $self->loc(join(
                 "",
-                "Required if you want undo and you do not use transaction. ",
+                "Required if you pass -undo_action=>'undo'. ",
                 "For more details on undo protocol, ",
                 "see L<Rinci::function::Undo>.")),
         };
@@ -132,36 +132,17 @@ sub _fdoc_gen {
                              "with same arguments has the same effect as ".
                                  "single invocation).")
         if $feat->{idempotent};
-    if ($feat->{tx} && $feat->{tx}{req}) {
-        push @ft, $self->loc("This function requires transactions.");
-    } elsif ($feat->{tx} && $feat->{tx}{use}) {
-        push @ft, $self->loc("This function can use transactions.")
-    }
-    push @ft, $self->loc("This function can start a new transaction.")
-        if $feat->{tx} && $feat->{tx}{start};
-    push @ft, $self->loc("This function can end (commit) transactions.")
-        if $feat->{tx} && $feat->{tx}{end};
     if ($feat->{tx}) {
-        $spargs{-tx_manager} = {
-            type => 'obj',
-            summary => $self->loc(join(
-                "",
-                "Instance of transaction manager object, ",
-                "usually L<Perinci::Tx::Manager>. Usually you do not have to ",
-                "pass this yourself, L<Perinci::Access::InProcess> will do it ",
-                "for you. For more details on transactions, see ",
-                "L<Rinci::function::Transaction>.")),
-        },
-        $spargs{-tx_action} = {
+        die "Sorry, I only support transaction protocol v=2"
+            unless $feat->{tx}{v} == 2;
+        push @ft, $self->loc("This function supports transactions.");
+        $spargs{$_} = {
             type => 'str',
             summary => $self->loc(join(
                 "",
-                "You currently can set this to 'rollback'. ",
-                "Usually you do not have to ",
-                "pass this yourself, L<Perinci::Access::InProcess> will do it ",
-                "for you. For more details on transactions, see ",
-                "L<Rinci::function::Transaction>.")),
-        },
+                "For more information on transaction, see ",
+                "L<Rinci::Transaction>.")),
+        } for qw(-tx_action -tx_action_id -tx_v -tx_is_rollback),
     }
     $self->add_doc_lines(join(" ", @ft), "", "") if @ft;
 
@@ -178,7 +159,7 @@ sub _fdoc_gen {
             $self->add_doc_lines(join(
                 "",
                 "=item * B<", $name, ">",
-                ($pa->{schema}[1]{req} ? '*' : ''), ' => ',
+                ($pa->{req} ? '*' : ''), ' => ',
                 "I<", $pa->{human_arg}, ">",
                 (defined($pa->{human_arg_default}) ?
                      " (" . $self->loc("default") .
@@ -222,6 +203,7 @@ sub _fdoc_gen {
     }
 
     $self->add_doc_lines($self->loc("Return value") . ':', "");
+    my $rn = $p->{orig_meta}{result_naked} // $p->{meta}{result_naked};
     $self->add_doc_lines($self->_md2pod($self->loc(join(
         "",
         "Returns an enveloped result (an array). ",
@@ -231,7 +213,7 @@ sub _fdoc_gen {
         "200. Third element (result) is optional, the actual result. Fourth ",
         "element (meta) is called result metadata and is optional, a hash ",
         "that contains extra information."))), "")
-        unless $p->{schema}{result_naked};
+        unless $rn;
 
     # XXX result summary
 
@@ -257,6 +239,8 @@ sub doc_gen_functions {
         "",
     );
 
+    # XXX if module uses Perinci::Exporter, show a basic usage for importing
+
     # XXX categorize functions based on tags
     for my $url (sort keys %$pff) {
         my $p = $pff->{$url};
@@ -278,7 +262,7 @@ Perinci::To::POD - Generate POD documentation from Rinci package metadata
 
 =head1 VERSION
 
-version 0.26
+version 0.27
 
 =head1 AUTHOR
 
